@@ -7,7 +7,7 @@ from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.common.forms import DynamicModelForm
 
-from .classes import ImportSetupActionBackend
+from .classes import ImportSetupActionBackend, ImportSetupBackend
 from .models import ImportSetupAction, ImportSetup
 
 
@@ -72,7 +72,7 @@ class ImportSetupBackendSelectionForm(forms.Form):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.fields['backend'].choices = ImportSetupActionBackend.get_choices()
+        self.fields['backend'].choices = ImportSetupBackend.get_choices()
 
 
 class ImportSetupBackendDynamicForm(DynamicModelForm):
