@@ -9,10 +9,10 @@ from .icons import (
     icon_import_setup_action_backend_selection,
     icon_import_setup_backend_selection, icon_import_setup_delete,
     icon_import_setup_edit, icon_import_setup_process,
-    icon_import_setup_item_delete, icon_import_setup_item_process,
-    icon_import_setup_clear, icon_import_setup_items_list,
-    icon_import_setup_list, icon_import_setup_populate,
-    icon_model_filer_load, icon_model_filer_save
+    icon_import_setup_item_delete, icon_import_setup_item_document_list,
+    icon_import_setup_item_process, icon_import_setup_clear,
+    icon_import_setup_items_list, icon_import_setup_list,
+    icon_import_setup_populate, icon_model_filer_load, icon_model_filer_save
 )
 from .permissions import (
     permission_import_setup_create, permission_import_setup_delete,
@@ -123,6 +123,12 @@ link_import_setup_multiple_clear = Link(
     icon_class=icon_import_setup_clear, text=_('Clear items'),
     view='importer:import_setup_multiple_clear'
 )
+link_import_setup_item_document_list = Link(
+    args='resolved_object.pk',
+    icon_class=icon_import_setup_item_document_list,
+    permissions=(permission_import_setup_view,), text=_('Documents'),
+    view='importer:import_setup_item_document_list'
+)
 link_import_setup_items_list = Link(
     args='resolved_object.pk',
     icon_class=icon_import_setup_items_list,
