@@ -7,9 +7,9 @@ from .views import (
     ImportSetupCreateView, ImportSetupDeleteView, ImportSetupEditView,
     ImportSetupProcessView, ImportSetupClearView, ImportSetupListView,
     ImportSetupPopulateView, ImportSetupItemDeleteView,
-    ImportSetupItemListView, ImportSetupItemLoadView,
-    ImportSetupItemProcessView, ImportSetupItemSaveConfirmView,
-    ImportSetupItemSaveDownloadView
+    ImportSetupItemDocumentListView, ImportSetupItemListView,
+    ImportSetupItemLoadView, ImportSetupItemProcessView,
+    ImportSetupItemSaveConfirmView, ImportSetupItemSaveDownloadView
 )
 
 urlpatterns_import_setup = [
@@ -121,6 +121,11 @@ urlpatterns_import_setup_items = [
         name='import_setup_item_multiple_delete',
         view=ImportSetupItemDeleteView.as_view()
     ),
+    url(
+        regex=r'^import_setups/items/(?P<import_setup_item_id>\d+)/documents/$',
+        name='import_setup_item_document_list',
+        view=ImportSetupItemDocumentListView.as_view()
+    ),
     url(
         regex=r'^import_setups/items/multiple/process/$',
         name='import_setup_item_multiple_process',
