@@ -15,6 +15,7 @@ from mayan.apps.common.generics import (
 )
 from mayan.apps.common.mixins import ExternalObjectMixin
 from mayan.apps.common.models import SharedUploadedFile
+from mayan.apps.documents.views.document_views import DocumentListView
 
 from .classes import ImportSetupActionBackend, ImportSetupBackend, ModelFiler
 from .forms import (
@@ -540,6 +541,40 @@ class ImportSetupItemDeleteView(MultipleObjectConfirmActionView):
         instance.delete()
 
 
+class ImportSetupItemDocumentListView(
+    ExternalObjectMixin, DocumentListView
+):
+    external_object_class = ImportSetupItem
+    external_object_permission = permission_import_setup_view
+    external_object_pk_url_kwarg = 'import_setup_item_id'
+
+    def get_document_queryset(self):
+        return self.external_object.documents.all()
+
+    def get_extra_context(self):
+        context = super().get_extra_context()
+        context.update(
+            {
+                'import_setup': self.external_object.import_setup,
+                'import_setup_item': self.external_object,
+                'navigation_object_list': (
+                    'import_setup', 'import_setup_item'
+                ),
+                'no_results_text': _(
+                    'This view will list the documents that were created '
+                    'by an import setup item.'
+                ),
+                'no_results_title': _(
+                    'There are no documents for this import setup item.'
+                ),
+                'title': _(
+                    'Document created from import setup item: %s'
+                ) % self.external_object,
+            }
+        )
+        return context
+
+
 class ImportSetupItemListView(ExternalObjectMixin, SingleObjectListView):
     external_object_class = ImportSetup
     external_object_permission = permission_import_setup_view
